# Generated by Django 3.1.1 on 2020-10-03 17:48

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("timezones", "0002_timezonedata_timezones"),
    ]

    operations = [
        migrations.AlterField(
            model_name="timezonedata",
            name="utc_offset",
            field=models.CharField(
                help_text="UTC offset of the timezone", max_length=255
            ),
        ),
    ]
