{% load timezones_versioned_static %}

<link rel="stylesheet" href="{% timezones_static 'timezones/css/aa-bootstrap-fix.min.css' %}">
<link rel="stylesheet" href="{% timezones_static 'timezones/css/timezones.min.css' %}">
