{% extends 'allianceauth/base.html' %}

{% load i18n %}

{% block page_title %}{% translate "Time Zones" %}{% endblock %}

{% block content %}
    <div class="aa-timezones">
        <div class="aa-timezones-header">
            <h1 class="page-header text-center">{% translate "Time Zones" %}</h1>
        </div>

        <div class="aa-timezones-body">
            {% block aa_timezones_body %}{% endblock %}
        </div>

        <div class="aa-timezones-footer">
            {% include "timezones/partials/footer/app-translation-footer.html" %}
        </div>
    </div>
{% endblock %}
